@@ -1,8 +1,10 @@
 #!/bin/sh
 
-VERSION="0.9.14"
+VERSION="0.9.18"
 OUT="$1"
 
+echo '#include "iw.h"' > "$OUT"
+
 if head=`git rev-parse --verify HEAD 2>/dev/null`; then
 	git update-index --refresh --unmerged > /dev/null
 	descr=$(git describe)
@@ -11,7 +13,6 @@ if head=`git rev-parse --verify HEAD 2>/dev/null`; then
 	# is correct...
 	[ "${descr%%-*}" = "v$VERSION" ] || exit 2
 
-	echo -n 'const char iw_version[] = "' > "$OUT"
 	v="${descr#v}"
 	if git diff-index --name-only HEAD | read dummy ; then
 		v="$v"-dirty
@@ -20,4 +21,4 @@ else
 	v="$VERSION"
 fi
 
-echo "const char iw_version[] = \"$v\";" > "$OUT"
+echo "const char iw_version[] = \"$v\";" >> "$OUT"
